package com.dcsoft.system.camera.service;

import com.dcsoft.system.camera.domain.TbCameraWarn;

import java.util.List;

/**
 * 视频预警Service接口
 *
 * @author nichun
 * @date 2023-09-20
 */
public interface ITbCameraWarnService
{
    /**
     * 查询视频预警
     *
     * @param id 视频预警主键
     * @return 视频预警
     */
    public TbCameraWarn selectTbCameraWarnById(Long id);

    /**
     * 查询视频预警列表
     *
     * @param tbCameraWarn 视频预警
     * @return 视频预警集合
     */
    public List<TbCameraWarn> selectTbCameraWarnList(TbCameraWarn tbCameraWarn);

    /**
     * 新增视频预警
     *
     * @param tbCameraWarn 视频预警
     * @return 结果
     */
    public int insertTbCameraWarn(TbCameraWarn tbCameraWarn);

    /**
     * 修改视频预警
     *
     * @param tbCameraWarn 视频预警
     * @return 结果
     */
    public int updateTbCameraWarn(TbCameraWarn tbCameraWarn);

    /**
     * 批量删除视频预警
     *
     * @param ids 需要删除的视频预警主键集合
     * @return 结果
     */
    public int deleteTbCameraWarnByIds(Long[] ids);

    /**
     * 删除视频预警信息
     *
     * @param id 视频预警主键
     * @return 结果
     */
    public int deleteTbCameraWarnById(Long id);
}
